@@ -143,8 +143,8 @@ class Parameters:
         119: PoolMode("ID_Ba_Sw_akt", True),
         120: Unknown("ID_Einst_RTypMK1_akt"),
         121: Unknown("ID_Einst_RTypMK2_akt"),
-        122: Unknown("ID_Einst_TDC_Ein_akt"),
-        123: Unknown("ID_Einst_TDC_Aus_akt"),
+        122: Kelvin("ID_Einst_TDC_Ein_akt"),
+        123: Kelvin("ID_Einst_TDC_Aus_akt"),
         124: Celsius("ID_Einst_TDC_Max_akt", True),
         125: Unknown("ID_Einst_HysHzExEn_akt"),
         126: Unknown("ID_Einst_HysBwExEn_akt"),
@@ -904,7 +904,7 @@ class Parameters:
         880: Unknown("ID_Waermemenge_Datum"),
         881: SolarMode("ID_Einst_Solar_akt", True),
         882: Unknown("ID_BSTD_Solar"),
-        883: Unknown("ID_Einst_TDC_Koll_Max_akt"),
+        883: Celsius("ID_Einst_TDC_Koll_Max_akt"),
         884: Unknown("ID_Einst_Akt_Kuehlung_akt"),
         885: Unknown("ID_Einst_Vorlauf_VBO_akt"),
         886: Unknown("ID_Einst_KRHyst_akt"),
